package javax.swing;

import java.awt.image.FilteredImageSource;
import java.awt.Toolkit;
import java.awt.Image;
import java.awt.image.RGBImageFilter;

public class GrayFilter extends RGBImageFilter
{
    private boolean brighter;
    private int percent;
    
    public static Image createDisabledImage(Image image) {
        return Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(image.getSource(), new GrayFilter(true, 50)));
    }
    
    public GrayFilter(boolean brighter, int percent) {
        this.brighter = brighter;
        this.percent = percent;
        this.canFilterIndexColorModel = true;
    }
    
    @Override
    public int filterRGB(int n, int n2, int n3) {
        int n4 = (int)((0.3 * (double)(n3 >> 16 & 0xFF) + 0.59 * (double)(n3 >> 8 & 0xFF) + 0.11 * (double)(n3 & 0xFF)) / 3.0);
        int n5;
        if (this.brighter) {
            n5 = 255 - (255 - n4) * (100 - this.percent) / 100;
        }
        else {
            n5 = n4 * (100 - this.percent) / 100;
        }
        if (n5 < 0) {
            n5 = 0;
        }
        if (n5 > 255) {
            n5 = 255;
        }
        return (n3 & 0xFF000000) | n5 << 16 | n5 << 8 | n5 << 0;
    }
}
